#!/usr/bin/perl

# Helper script for mutt to create a list of send-hooks which enable
# crypt_autoencrypt for known GnuPG keys.

# Copyright (C) 2009-2013  Simon Ruderich
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


use strict;
use warnings;

open my $gpg, '-|', 'gpg --list-keys --with-colons --fixed-list-mode' or die $!;
while (<$gpg>) {
    next if not /^uid:/;

    # We don't skip invalid, deleted, revoked, expired and not-trusted UIDs to
    # prevent sending an unencrypted mail when e.g. a key is revoked or
    # expired; GnuPG will warn if we use any of them. If you really want to
    # skip those UIDs (not recommended), uncomment the next line.
    #next if /^uid:[idren]:/;

    next if not /<(.+?@.+?)>:/;
    print "send-hook '~t $1' 'set crypt_autoencrypt=yes'\n";
}
close $gpg or die $!;
